@@ -38,6 +38,8 @@ import com.google.common.collect.Ordering;
 import com.google.common.collect.Range;
 import com.google.common.util.concurrent.UncheckedExecutionException;
 import com.google.testing.junit.testparameterinjector.junit5.TestInfo.TestInfoParameter;
+import com.google.testing.junit.testparameterinjector.junit5.TestParameter.InternalImplementationOfThisParameter;
+import com.google.testing.junit.testparameterinjector.junit5.TestParameterAnnotation.DefaultValidator;
 import java.io.Serializable;
 import java.lang.annotation.Annotation;
 import java.lang.annotation.Retention;
@@ -64,7 +66,6 @@ import javax.annotation.Nullable;
  * @see TestParameterAnnotation
  */
 final class TestParameterAnnotationMethodProcessor implements TestMethodProcessor {
-
   /**
    * Class to hold an annotation type and origin and one of the values as returned by the {@code
    * value()} method.
@@ -184,7 +185,11 @@ final class TestParameterAnnotationMethodProcessor implements TestMethodProcesso
     Annotation annotation = annotationWithMetadata.annotation();
     TestParameterAnnotation testParameter =
         annotation.annotationType().getAnnotation(TestParameterAnnotation.class);
-    Class<? extends TestParameterValueProvider> valueProvider = testParameter.valueProvider();
+    Class<? extends TestParameterValueProvider> valueProvider =
+        annotation.annotationType() == TestParameter.class
+            // Workaround for b/287424109:
+            ? TEST_PARAMETER_VALUE_PROVIDER
+            : testParameter.valueProvider();
     try {
       return FluentIterable.from(
               valueProvider
@@ -975,6 +980,12 @@ final class TestParameterAnnotationMethodProcessor implements TestMethodProcesso
                                           field.getName(),
                                           GenericParameterContext.create(field, testClass))))
                   .toList());
+
+      if (isKotlinClass(testClass)) {
+        annotations =
+            applyKotlinDuplicateAnnotationWorkaround(annotations, annotationType, testClass);
+      }
+
       if (!annotations.isEmpty()) {
         return toTestParameterValueList(annotations, origin);
       }
@@ -992,6 +1003,83 @@ final class TestParameterAnnotationMethodProcessor implements TestMethodProcesso
     return ImmutableList.of();
   }
 
+  /**
+   * Hack to fix a 2025 Kotlin change that causes the field/parameter of a primary constructor to
+   * get its annotation on both the field and the constructor parameter.
+   *
+   * <p>Example:
+   *
+   * {@snippet :
+   *   @RunWith(TestParameterInjector::class)
+   *   class ExampleTest(@TestParameter private val isEnabled: Boolean)
+   * }
+   *
+   * In this heuristic, we look for fields with the same name and type as a constructor parameter.
+   * If we find one, we assume it's the same parameter, and drop it.
+   *
+   * <p>For more info, see: https://github.com/google/TestParameterInjector/issues/49
+   */
+  private static List<AnnotationWithMetadata> applyKotlinDuplicateAnnotationWorkaround(
+      List<AnnotationWithMetadata> fieldAnnotations,
+      Class<? extends Annotation> annotationType,
+      Class<?> testClass) {
+    List<AnnotationWithMetadata> constructorAnnotations =
+        getAnnotationWithMetadataListWithType(
+            TestParameterInjectorUtils.getOnlyConstructor(testClass), annotationType, testClass);
+
+    ImmutableList.Builder<AnnotationWithMetadata> resultBuilder = ImmutableList.builder();
+    for (AnnotationWithMetadata fieldAnnotation : fieldAnnotations) {
+      List<AnnotationWithMetadata> matchingConstructorAnnotations =
+          FluentIterable.from(constructorAnnotations)
+              .filter(
+                  constructorAnnotation ->
+                      fieldAnnotation.annotation().equals(constructorAnnotation.annotation())
+                          && fieldAnnotation
+                              .paramClass()
+                              .equals(constructorAnnotation.paramClass()))
+              .toList();
+
+      if (matchingConstructorAnnotations.isEmpty()) {
+        // Most common case: No suspect fields/parameters.
+        resultBuilder.add(fieldAnnotation);
+      } else {
+        if (matchingConstructorAnnotations.get(0).paramName().isPresent()) {
+          if (FluentIterable.from(matchingConstructorAnnotations)
+              .filter(
+                  constructorAnnotation ->
+                      fieldAnnotation.paramName().equals(constructorAnnotation.paramName()))
+              .isEmpty()) {
+            // No suspect fields/parameters because their names don't match.
+            resultBuilder.add(fieldAnnotation);
+          } else {
+            // Skip this field because it has the same name + type as a constructor
+            // parameter. Therefore, it is almost certainly an artefact of the Kotlin-Java
+            // translation of a field+parameter in the primary constructor..
+          }
+        } else {
+          // This field has the same type as a constructor parameter, but this code was built
+          // without parameter names, so it may or may not be the same parameter.
+          throw new RuntimeException(
+              String.format(
+                  "%s: Found a Kotlin field (%s) and constructor parameter with the same type. This"
+                      + " may be an artefact of the Kotlin-Java translation of a field+parameter in"
+                      + " the primary constructor. However, TestParameterInjector needs to be built"
+                      + " with access to parameter names to be able to confirm.\n"
+                      + "\n"
+                      + "To fix this error, either:\n"
+                      + "  - Use `@param:TestParameter` instead of `@TestParameter` on the primary"
+                      + " constructor parameter.\n"
+                      + "  - Build this test with the `-parameters` compiler option. In  Maven, you"
+                      + " do this by adding <javaParameters>true</javaParameters> to the"
+                      + " kotlin-maven-plugin's configuration.",
+                  testClass.getSimpleName(), fieldAnnotation.paramName().get()));
+        }
+      }
+    }
+
+    return resultBuilder.build();
+  }
+
   private static ImmutableList<List<TestParameterValueHolder>> toTestParameterValueList(
       List<AnnotationWithMetadata> annotationWithMetadatas, Origin origin) {
     return FluentIterable.from(annotationWithMetadatas)
@@ -1244,7 +1332,11 @@ final class TestParameterAnnotationMethodProcessor implements TestMethodProcesso
       List<TestParameterValueHolder> testParameterValues) {
     TestParameterAnnotation annotation =
         annotationType.getAnnotation(TestParameterAnnotation.class);
-    Class<? extends TestParameterValidator> validator = annotation.validator();
+    Class<? extends TestParameterValidator> validator =
+        annotationType == TestParameter.class
+            // Workaround for b/287424109:
+            ? TEST_PARAMETER_VALIDATOR
+            : annotation.validator();
     try {
       return validator
           .getConstructor()
@@ -1312,7 +1404,11 @@ final class TestParameterAnnotationMethodProcessor implements TestMethodProcesso
       Class<? extends Annotation> annotationType, Optional<Class<?>> paramClass) {
     TestParameterAnnotation testParameter =
         annotationType.getAnnotation(TestParameterAnnotation.class);
-    Class<? extends TestParameterValueProvider> valueProvider = testParameter.valueProvider();
+    Class<? extends TestParameterValueProvider> valueProvider =
+        annotationType == TestParameter.class
+            // Workaround for b/287424109:
+            ? TEST_PARAMETER_VALUE_PROVIDER
+            : testParameter.valueProvider();
     try {
       return valueProvider.getConstructor().newInstance().getValueType(annotationType, paramClass);
     } catch (Exception e) {
@@ -1366,4 +1462,46 @@ final class TestParameterAnnotationMethodProcessor implements TestMethodProcesso
 
     return resultBuilder.build();
   }
+
+  private static final Class<? extends TestParameterValidator> TEST_PARAMETER_VALIDATOR =
+      DefaultValidator.class;
+  private static final Class<? extends TestParameterValueProvider> TEST_PARAMETER_VALUE_PROVIDER =
+      InternalImplementationOfThisParameter.class;
+
+  static {
+    // Validate our constants.
+    // Under Android 23, we need to use the constants because normal reflection might not work.
+    // Since normal reflection might not work under Android, we don't validate the constants there.
+    if (!isAndroid()) {
+      TestParameterAnnotation annotation =
+          TestParameter.class.getAnnotation(TestParameterAnnotation.class);
+      if (!annotation.validator().equals(TEST_PARAMETER_VALIDATOR)) {
+        throw new AssertionError(
+            String.format(
+                "The value of validator() in the @TestParameterAnnotation annotation in"
+                    + " TestParameter.java has changed to %s. Update the constant in"
+                    + " TestParameterAnnotationMethodProcessor, which currently has value %s, to"
+                    + " match",
+                annotation.validator().getName(), TEST_PARAMETER_VALIDATOR.getName()));
+      }
+      if (!annotation.valueProvider().equals(TEST_PARAMETER_VALUE_PROVIDER)) {
+        throw new AssertionError(
+            String.format(
+                "The value of valueProvider() in the @TestParameterAnnotation annotation in"
+                    + " TestParameter.java has changed to %s. Update the constant in"
+                    + " TestParameterAnnotationMethodProcessor, which currently has value %s, to"
+                    + " match",
+                annotation.valueProvider().getName(), TEST_PARAMETER_VALUE_PROVIDER.getName()));
+      }
+    }
+  }
+
+  private static boolean isAndroid() {
+    return System.getProperty("java.runtime.name", "").contains("Android");
+  }
+
+  private static boolean isKotlinClass(Class<?> clazz) {
+    return FluentIterable.from(clazz.getDeclaredAnnotations())
+        .anyMatch(annotation -> annotation.annotationType().getName().equals("kotlin.Metadata"));
+  }
 }
